import bodyParser from "body-parser";
import express, { Application } from "express";
import Info from "./hooks/info";
import AppLogger from "./logger";
import Error from "./hooks/error";
import Warn from "./hooks/warn";

export default class Express {
    private app: Application;

    private port = process.env.EXPRESS_PORT!;

    public start() {
        this.setupApp();
        this.setupRoutes();
        this.setupListen();
    }

    private setupApp() {
        this.app = express();
        this.app.use(bodyParser.json());
    }

    private setupRoutes() {
        this.app.post("/info", Info);
        this.app.post("/warn", Warn);
        this.app.post("/error", Error);
    }

    private setupListen() {
        this.app.listen(this.port, () => {
            AppLogger.LogVerbose("internal", "express", `Initialised express at port ${this.port}`);
        });
    }
}
